@@ -36,11 +36,13 @@
 #include <KMessageBox>
 #include <KApplication>
 #include <KDiskFreeSpaceInfo>
+
 #include <QMouseEvent>
 #include <QMenu>
 #include <QToolButton>
 #include <QFile>
 #include <QDir>
+#include <QDesktopWidget>
 
 
 RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidget *parent) :
@@ -56,7 +58,6 @@ RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidge
     //video_frame->setAttribute(Qt::WA_PaintOnScreen);
     device_selector->setCurrentIndex(KdenliveSettings::defaultcapture());
     connect(device_selector, SIGNAL(currentIndexChanged(int)), this, SLOT(slotVideoDeviceChanged(int)));
-
     // Video widget holder
     QVBoxLayout *l = new QVBoxLayout;
     l->setContentsMargins(0, 0, 0, 0);
@@ -66,8 +67,8 @@ RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidge
     createVideoSurface();
 
     QToolBar *toolbar = new QToolBar(this);
-    QHBoxLayout *layout = new QHBoxLayout;
-    layout->setContentsMargins(0, 0, 0, 0);
+    QHBoxLayout *hlayout = new QHBoxLayout;
+    hlayout->setContentsMargins(0, 0, 0, 0);
     m_playIcon = KIcon("media-playback-start");
     m_pauseIcon = KIcon("media-playback-pause");
 
@@ -103,7 +104,6 @@ RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidge
     m_previewSettings = new QAction(i18n("Recording Preview"), this);
     m_previewSettings->setCheckable(true);
 
-
     rec_options->setMenu(menu);
     menu->addAction(m_previewSettings);
 
@@ -113,30 +113,30 @@ RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidge
     connect(configAction, SIGNAL(triggered()), this, SLOT(slotConfigure()));
     configAction->setCheckable(false);
 
-    layout->addWidget(toolbar);
-    layout->addWidget(&m_logger);
-    layout->addWidget(&m_dvinfo);
+    hlayout->addWidget(toolbar);
+    hlayout->addWidget(&m_logger);
+    hlayout->addWidget(&m_dvinfo);
     m_logger.setMaxCount(10);
     m_logger.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_logger.setFrame(false);
     //m_logger.setInsertPolicy(QComboBox::InsertAtTop);
-
+    
     m_freeSpace = new KCapacityBar(KCapacityBar::DrawTextInline, this);
     m_freeSpace->setMaximumWidth(150);
     QFontMetricsF fontMetrics(font());
     m_freeSpace->setMaximumHeight(fontMetrics.height() * 1.2);
     slotUpdateFreeSpace();
-    layout->addWidget(m_freeSpace);
+    hlayout->addWidget(m_freeSpace);
     connect(&m_spaceTimer, SIGNAL(timeout()), this, SLOT(slotUpdateFreeSpace()));
     m_spaceTimer.setInterval(30000);
     m_spaceTimer.setSingleShot(false);
 
-    control_frame_firewire->setLayout(layout);
+    control_frame_firewire->setLayout(hlayout);
     m_displayProcess = new QProcess;
     m_captureProcess = new QProcess;
 
     connect(m_captureProcess, SIGNAL(stateChanged(QProcess::ProcessState)), this, SLOT(slotProcessStatus(QProcess::ProcessState)));
-    connect(m_captureProcess, SIGNAL(readyReadStandardError()), this, SLOT(slotReadDvgrabInfo()));
+    connect(m_captureProcess, SIGNAL(readyReadStandardError()), this, SLOT(slotReadProcessInfo()));
     
     QString videoDriver = KdenliveSettings::videodrivername();
 #if QT_VERSION >= 0x040600
@@ -164,6 +164,13 @@ RecMonitor::RecMonitor(Kdenlive::MONITORID name, MonitorManager *manager, QWidge
     setenv("SDL_VIDEO_ALLOW_SCREENSAVER", "1", 1);
 
     kDebug() << "/////// BUILDING MONITOR, ID: " << videoSurface->winId();
+#if KDE_IS_VERSION(4,7,0)
+    m_infoMessage = new KMessageWidget;
+    QVBoxLayout *s =  static_cast <QVBoxLayout *> (layout());
+    s->insertWidget(1, m_infoMessage);
+    m_infoMessage->hide();
+#endif
+    
     slotVideoDeviceChanged(device_selector->currentIndex());
     m_previewSettings->setChecked(KdenliveSettings::enable_recording_preview());
     connect(m_previewSettings, SIGNAL(triggered(bool)), this, SLOT(slotChangeRecordingPreview(bool)));
@@ -192,6 +199,8 @@ void RecMonitor::slotSwitchFullScreen()
 
 void RecMonitor::stop()
 {
+    // Special case: when recording audio only, do not stop so that we can do voiceover.
+    if (device_selector->currentIndex() == SCREENGRAB || (device_selector->currentIndex() == VIDEO4LINUX && !rec_video->isChecked())) return;
     slotStopCapture();
 }
 
@@ -224,9 +233,18 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
 {
     QString capturefile;
     QString capturename;
+#if KDE_IS_VERSION(4,7,0)
+    if (m_infoMessage->isVisible()) {
+#if KDE_IS_VERSION(4,10,0)
+	m_infoMessage->animatedHide();
+#else    
+	QTimer::singleShot(0, m_infoMessage, SLOT(animatedHide()));
+#endif
+    }
+#endif
     m_previewSettings->setEnabled(ix == VIDEO4LINUX || ix == BLACKMAGIC);
-    rec_audio->setVisible(ix == VIDEO4LINUX);
-    rec_video->setVisible(ix == VIDEO4LINUX);
+    control_frame->setVisible(ix == VIDEO4LINUX);
+    m_playAction->setVisible(ix != SCREENGRAB);
     m_fwdAction->setVisible(ix == FIREWIRE);
     m_discAction->setVisible(ix == FIREWIRE);
     m_rewAction->setVisible(ix == FIREWIRE);
@@ -250,12 +268,23 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         m_fwdAction->setEnabled(false);
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(false);
-        if (KdenliveSettings::rmd_path().isEmpty()) {
-            QString rmdpath = KStandardDirs::findExe("recordmydesktop");
-            if (rmdpath.isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("Recordmydesktop utility not found,\n please install it for screen grabs")));
-            else KdenliveSettings::setRmd_path(rmdpath);
-        }
-        if (!KdenliveSettings::rmd_path().isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", m_capturePath)));
+	if (KdenliveSettings::ffmpegpath().isEmpty()) {
+	    QString exepath = KStandardDirs::findExe("ffmpeg");
+	    if (exepath.isEmpty()) {
+		// Check for libav version
+		exepath = KStandardDirs::findExe("avconv");
+	    }
+	    if (exepath.isEmpty()) showWarningMessage(i18n("ffmpeg or avconv not found,\n please install it for screen grabs"));
+	    else KdenliveSettings::setFfmpegpath(exepath);
+	}
+        if (!KdenliveSettings::ffmpegpath().isEmpty()) {
+	    if (!Render::checkX11Grab()) {
+		// FFmpeg does not support screen grab
+		showWarningMessage(i18n("Your FFmpeg / Libav installation\n does not support screen grab"), "dialog-warning");
+		m_recAction->setEnabled(false);
+	    }
+	    else video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", m_capturePath)));
+	}
         //video_frame->setText(i18n("Press record button\nto start screen capture"));
         break;
     case VIDEO4LINUX:
@@ -267,7 +296,7 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(true);
         capturefile = m_capturePath;
-        if (!capturefile.endsWith("/")) capturefile.append("/");
+        if (!capturefile.endsWith('/')) capturefile.append('/');
         capturename = KdenliveSettings::decklink_filename();
         capturename.append("xxx.");
         capturename.append(KdenliveSettings::decklink_extension());
@@ -284,12 +313,14 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         // Check that dvgab is available
         if (KdenliveSettings::dvgrab_path().isEmpty()) {
             QString dvgrabpath = KStandardDirs::findExe("dvgrab");
-            if (dvgrabpath.isEmpty()) video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), i18n("dvgrab utility not found,\n please install it for firewire capture")));
+            if (dvgrabpath.isEmpty()) {
+		showWarningMessage(i18n("dvgrab utility not found,\n please install it for firewire capture"));
+	    }
             else KdenliveSettings::setDvgrab_path(dvgrabpath);
         } else {
             // Show capture info
             capturefile = m_capturePath;
-            if (!capturefile.endsWith("/")) capturefile.append("/");
+            if (!capturefile.endsWith('/')) capturefile.append('/');
             capturename = KdenliveSettings::dvgrabfilename();
             if (capturename.isEmpty()) capturename = "capture";
             QString extension;
@@ -340,10 +371,11 @@ QPixmap RecMonitor::mergeSideBySide(const QPixmap& pix, const QString &txt)
 void RecMonitor::checkDeviceAvailability()
 {
     if (!KIO::NetAccess::exists(KUrl(KdenliveSettings::video4vdevice()), KIO::NetAccess::SourceSide , this)) {
-        m_playAction->setEnabled(false);
-        m_recAction->setEnabled(false);
+        rec_video->setChecked(false);
+	rec_video->setEnabled(false);
         video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice())));
     } else {
+	rec_video->setEnabled(true);
         video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Press play or record button\nto start video capture\nFiles will be saved in:\n%1", m_capturePath)));
     }
 }
@@ -385,8 +417,8 @@ void RecMonitor::slotStopCapture()
     // stop capture
     if (!m_isCapturing && !m_isPlaying) return;
     videoBox->setHidden(true);
-    rec_audio->setEnabled(true);
-    rec_video->setEnabled(true);
+    control_frame->setEnabled(true);
+    slotActivateMonitor();
     switch (device_selector->currentIndex()) {
     case FIREWIRE:
         m_captureProcess->write("\e", 2);
@@ -394,10 +426,8 @@ void RecMonitor::slotStopCapture()
         m_isPlaying = false;
         break;
     case SCREENGRAB:
-        m_captureProcess->write("q\n", 3);
-        m_captureProcess->terminate();
-        video_frame->setText(i18n("Encoding captured video..."));
-        QTimer::singleShot(1000, m_captureProcess, SLOT(kill()));
+	m_captureProcess->terminate();
+        QTimer::singleShot(1500, m_captureProcess, SLOT(kill()));
         break;
     case VIDEO4LINUX:
     case BLACKMAGIC:
@@ -450,8 +480,9 @@ void RecMonitor::slotStartPreview(bool play)
     QString path;
     MltVideoProfile profile;
     QString producer;
-    QStringList dvargs = KdenliveSettings::dvgrabextra().simplified().split(" ", QString::SkipEmptyParts);
+    QStringList dvargs = KdenliveSettings::dvgrabextra().simplified().split(' ', QString::SkipEmptyParts);
     int ix = device_selector->currentIndex();
+    bool isXml;
     videoBox->setHidden(ix != VIDEO4LINUX && ix != BLACKMAGIC && ix != FIREWIRE);
     switch (ix) {
     case FIREWIRE:
@@ -500,10 +531,10 @@ void RecMonitor::slotStartPreview(bool play)
         path = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
         buildMltDevice(path);
         profile = ProfilesDialog::getVideoProfile(path);
-        producer = getV4lXmlPlaylist(profile);
+        producer = getV4lXmlPlaylist(profile, &isXml);
 
         //producer = QString("avformat-novalidate:video4linux2:%1?width:%2&height:%3&frame_rate:%4").arg(KdenliveSettings::video4vdevice()).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den);
-        if (!m_captureDevice->slotStartPreview(producer, true)) {
+        if (!m_captureDevice->slotStartPreview(producer, isXml)) {
             // v4l capture failed to start
             video_frame->setText(i18n("Failed to start Video4Linux,\ncheck your parameters..."));
             videoBox->setHidden(true);
@@ -535,12 +566,11 @@ void RecMonitor::slotStartPreview(bool play)
         break;
     }
 
-    rec_audio->setEnabled(false);
-    rec_video->setEnabled(false);
+    control_frame->setEnabled(false);
 
     if (device_selector->currentIndex() == FIREWIRE) {
         kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
-        m_displayProcess->start("ffplay", m_displayArgs);
+        m_displayProcess->start(KdenliveSettings::ffplaypath(), m_displayArgs);
         //video_frame->setText(i18n("Initialising..."));
     } else {
         // do something when starting screen grab
@@ -549,9 +579,7 @@ void RecMonitor::slotStartPreview(bool play)
 
 void RecMonitor::slotRecord()
 {
-    rec_audio->setEnabled(false);
-    rec_video->setEnabled(false);
-
+    m_error.clear();
     if (m_captureProcess->state() == QProcess::NotRunning && device_selector->currentIndex() == FIREWIRE) {
         slotStartPreview();
     }
@@ -570,7 +598,9 @@ void RecMonitor::slotRecord()
         m_logger.clear();
         m_recAction->setChecked(true);
         QString extension = "mpg";
-        if (device_selector->currentIndex() == SCREENGRAB) extension = "ogv"; //KdenliveSettings::screengrabextension();
+        if (device_selector->currentIndex() == SCREENGRAB) {
+	    extension = KdenliveSettings::grab_extension();
+	}
         else if (device_selector->currentIndex() == VIDEO4LINUX) {
             // TODO: when recording audio only, allow configuration?
             if (!rec_video->isChecked()) extension = "wav";
@@ -591,19 +621,23 @@ void RecMonitor::slotRecord()
         QString args;
         QString playlist;
         QString v4lparameters;
+	QStringList grabParameters;
         MltVideoProfile profile;
         bool showPreview;
+	bool isXml;
+	QString captureSize;
+	QRect screenSize = QApplication::desktop()->screenGeometry();
         QString capturename = KdenliveSettings::dvgrabfilename();
         if (capturename.isEmpty()) capturename = "capture";
 
         switch (device_selector->currentIndex()) {
         case VIDEO4LINUX:
-            slotActivateMonitor();
+            if (rec_video->isChecked()) slotActivateMonitor();
             path = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
             profile = ProfilesDialog::getVideoProfile(path);
             //m_videoBox->setRatio((double) profile.display_aspect_num / profile.display_aspect_den);
             buildMltDevice(path);
-            playlist = getV4lXmlPlaylist(profile);
+            playlist = getV4lXmlPlaylist(profile, &isXml);
 
             v4lparameters = KdenliveSettings::v4l_parameters();
 
@@ -642,16 +676,20 @@ void RecMonitor::slotRecord()
             showPreview = m_previewSettings->isChecked();
             if (!rec_video->isChecked()) showPreview = false;
 
-            if (m_captureDevice->slotStartCapture(v4lparameters, m_captureFile.path(), playlist, showPreview)) {
+            if (m_captureDevice->slotStartCapture(v4lparameters, m_captureFile.path(), playlist, showPreview, isXml)) {
                 videoBox->setHidden(false);
                 m_isCapturing = true;
                 m_recAction->setEnabled(false);
                 m_stopAction->setEnabled(true);
                 m_previewSettings->setEnabled(false);
+		control_frame->setEnabled(false);
             }
             else {
                 video_frame->setText(i18n("Failed to start Video4Linux,\ncheck your parameters..."));
                 videoBox->setHidden(true);
+		m_recAction->blockSignals(true);
+		m_recAction->setChecked(false);
+		m_recAction->blockSignals(false);
                 m_isCapturing = false;
             }
             break;
@@ -682,29 +720,34 @@ void RecMonitor::slotRecord()
             break;
 
         case SCREENGRAB:
-            switch (KdenliveSettings::rmd_capture_type()) {
-            case 0:
-                // Full screen capture, nothing special to do
-                break;
-            default:
+	    m_captureArgs << "-f" << "x11grab";
+	    if (KdenliveSettings::grab_follow_mouse()) m_captureArgs << "-follow_mouse" << "centered";
+	    if (!KdenliveSettings::grab_hide_frame()) m_captureArgs << "-show_region" << "1";
+            if (KdenliveSettings::grab_capture_type() == 0) {
+                // Full screen capture
+                captureSize = ":0.0";
+		m_captureArgs << "-s" << QString::number(screenSize.width()) + "x" + QString::number(screenSize.height());
+	    } else {
                 // Region capture
-                m_captureArgs << "--width" << QString::number(KdenliveSettings::rmd_width()) << "--height" << QString::number(KdenliveSettings::rmd_height());
-                if (!KdenliveSettings::rmd_follow_mouse()) {
-                    m_captureArgs << "-x" << QString::number(KdenliveSettings::rmd_offsetx()) << "-y" << QString::number(KdenliveSettings::rmd_offsety());
-                } else {
-                    m_captureArgs << "--follow-mouse";
-                    if (KdenliveSettings::rmd_hide_frame()) m_captureArgs << "--no-frame";
-                }
-                break;
+                m_captureArgs << "-s" << QString::number(KdenliveSettings::grab_width()) + "x" + QString::number(KdenliveSettings::grab_height());
+                captureSize = ":" + QString::number(KdenliveSettings::grab_offsetx()) + "." + QString::number(KdenliveSettings::grab_offsetx());
             }
-            if (KdenliveSettings::rmd_hide_mouse()) m_captureArgs << "--no-cursor";
+            // fps
+            m_captureArgs << "-r" << QString::number(KdenliveSettings::grab_fps());
+            if (KdenliveSettings::grab_hide_mouse()) captureSize.append("+nomouse");
+	    m_captureArgs << "-i" << captureSize;
+	    grabParameters = KdenliveSettings::grab_parameters().simplified().split(" ");
+	    m_captureArgs << grabParameters;
+	    m_captureArgs << path;
+	    
             m_isCapturing = true;
-            if (KdenliveSettings::rmd_capture_audio()) {
+	    m_recAction->setEnabled(false);
+            /*if (KdenliveSettings::rmd_capture_audio()) {
                 m_captureArgs << "--freq" << KdenliveSettings::rmd_freq();
                 m_captureArgs << "--channels" << QString::number(KdenliveSettings::rmd_audio_channels());
                 if (KdenliveSettings::rmd_use_jack()) {
                     m_captureArgs << "--use-jack";
-                    QStringList ports = KdenliveSettings::rmd_jackports().split(" ", QString::SkipEmptyParts);
+                    QStringList ports = KdenliveSettings::rmd_jackports().split(' ', QString::SkipEmptyParts);
                     for (int i = 0; i < ports.count(); ++i) {
                         m_captureArgs << ports.at(i);
                     }
@@ -716,15 +759,14 @@ void RecMonitor::slotRecord()
                     if (KdenliveSettings::rmd_alsa_buffer() > 0)
                         m_captureArgs << "--buffer-size" << QString::number(KdenliveSettings::rmd_alsa_buffer());
                 }
-            } else m_captureArgs << "--no-sound";
+            } else m_captureArgs << "--no-sound";*/
 
-            if (KdenliveSettings::rmd_fullshots()) m_captureArgs << "--full-shots";
-            m_captureArgs << "--v_bitrate" << QString::number(KdenliveSettings::rmd_bitrate());
-            m_captureArgs << "--v_quality" << QString::number(KdenliveSettings::rmd_quality());
-            m_captureArgs << "--workdir" << KdenliveSettings::currenttmpfolder();
-            m_captureArgs << "--fps" << QString::number(KdenliveSettings::rmd_fps()) << "-o" << m_captureFile.path();
-            m_captureProcess->start(KdenliveSettings::rmd_path(), m_captureArgs);
-            kDebug() << "// RecordMyDesktop params: " << m_captureArgs;
+            m_captureProcess->start(KdenliveSettings::ffmpegpath(), m_captureArgs);
+	    if (!m_captureProcess->waitForStarted()) {
+		// Problem launching capture app
+		showWarningMessage(i18n("Failed to start the capture application:\n%1", KdenliveSettings::ffmpegpath()));
+	    }
+            //kDebug() << "// Screen grab params: " << m_captureArgs;
             break;
         default:
             break;
@@ -734,7 +776,7 @@ void RecMonitor::slotRecord()
         if (device_selector->currentIndex() == FIREWIRE) {
             m_isCapturing = true;
             kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
-            m_displayProcess->start("ffplay", m_displayArgs);
+            m_displayProcess->start(KdenliveSettings::ffplaypath(), m_displayArgs);
             video_frame->setText(i18n("Initialising..."));
         }
     } else {
@@ -745,22 +787,62 @@ void RecMonitor::slotRecord()
     }
 }
 
-const QString RecMonitor::getV4lXmlPlaylist(MltVideoProfile profile) {
 
-    QString playlist = QString("<mlt title=\"capture\" LC_NUMERIC=\"C\"><profile description=\"v4l\" width=\"%1\" height=\"%2\" progressive=\"%3\" sample_aspect_num=\"%4\" sample_aspect_den=\"%5\" display_aspect_num=\"%6\" display_aspect_den=\"%7\" frame_rate_num=\"%8\" frame_rate_den=\"%9\" colorspace=\"%10\"/>").arg(profile.width).arg(profile.height).arg(profile.progressive).arg(profile.sample_aspect_num).arg(profile.sample_aspect_den).arg(profile.display_aspect_num).arg(profile.display_aspect_den).arg(profile.frame_rate_num).arg(profile.frame_rate_den).arg(profile.colorspace);
+void RecMonitor::showWarningMessage(const QString &text, bool logAction)
+{
+#if KDE_IS_VERSION(4,7,0)
+    m_infoMessage->setText(text);
+    m_infoMessage->setMessageType(KMessageWidget::Warning);
+    if (logAction) {
+	QAction *manualAction = new QAction(i18n("Show log"), this);
+	connect(manualAction, SIGNAL(triggered()), this, SLOT(slotShowLog()));
+	m_infoMessage->addAction(manualAction);
+    }
+#if KDE_IS_VERSION(4,10,0)
+    m_infoMessage->animatedShow();
+#else
+    QTimer::singleShot(0, m_infoMessage, SLOT(animatedShow()));
+#endif
+#else
+    if (!logAction) {
+	video_frame->setPixmap(mergeSideBySide(KIcon("dialog-warning").pixmap(QSize(50, 50)), text));
+	
+    }
+    else {
+	video_frame->setText(QString("<qt>" + text + "<br><a href=\"http://kde.org\">" + i18n("Show log") + "</a>"));
+	connect(video_frame, SIGNAL(linkActivated (const QString &)), this, SLOT(slotShowLog()));
+    }
+#endif
+}
+
+const QString RecMonitor::getV4lXmlPlaylist(MltVideoProfile profile, bool *isXml) 
+{
+    QString playlist;
+    if (rec_video->isChecked() && rec_audio->isChecked()) {
+	// We want to capture audio and video, use xml playlist
+	*isXml = true;
+	playlist = QString("<mlt title=\"capture\" LC_NUMERIC=\"C\"><profile description=\"v4l\" width=\"%1\" height=\"%2\" progressive=\"%3\" sample_aspect_num=\"%4\" sample_aspect_den=\"%5\" display_aspect_num=\"%6\" display_aspect_den=\"%7\" frame_rate_num=\"%8\" frame_rate_den=\"%9\" colorspace=\"%10\"/>").arg(profile.width).arg(profile.height).arg(profile.progressive).arg(profile.sample_aspect_num).arg(profile.sample_aspect_den).arg(profile.display_aspect_num).arg(profile.display_aspect_den).arg(profile.frame_rate_num).arg(profile.frame_rate_den).arg(profile.colorspace);
 
-    if (rec_video->isChecked()) {
         playlist.append(QString("<producer id=\"producer0\" in=\"0\" out=\"999999\"><property name=\"mlt_type\">producer</property><property name=\"length\">1000000</property><property name=\"eof\">loop</property><property name=\"resource\">video4linux2:%1?width:%2&amp;height:%3&amp;frame_rate:%4</property><property name=\"mlt_service\">avformat-novalidate</property></producer><playlist id=\"playlist0\"><entry producer=\"producer0\" in=\"0\" out=\"999999\"/></playlist>").arg(KdenliveSettings::video4vdevice()).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den));
-    }
+    
+        playlist.append(QString("<producer id=\"producer1\" in=\"0\" out=\"999999\"><property name=\"mlt_type\">producer</property><property name=\"length\">1000000</property><property name=\"resource\">alsa:%1?channels=%2</property><property name=\"audio_index\">0</property><property name=\"video_index\">-1</property><property name=\"mlt_service\">avformat-novalidate</property></producer><playlist id=\"playlist1\"><entry producer=\"producer1\" in=\"0\" out=\"999999\"/></playlist>").arg(KdenliveSettings::v4l_alsadevicename()).arg(KdenliveSettings::alsachannels()));
 
-    if (rec_audio->isChecked()) {
-        playlist.append(QString("<producer id=\"producer1\" in=\"0\" out=\"999999\"><property name=\"mlt_type\">producer</property><property name=\"length\">1000000</property><property name=\"eof\">loop</property><property name=\"resource\">alsa:%5</property><property name=\"audio_index\">0</property><property name=\"video_index\">-1</property><property name=\"mlt_service\">avformat-novalidate</property></producer><playlist id=\"playlist1\"><entry producer=\"producer1\" in=\"0\" out=\"999999\"/></playlist>").arg(KdenliveSettings::v4l_alsadevicename()));
+	playlist.append("<tractor id=\"tractor0\" title=\"video0\" global_feed=\"1\" in=\"0\" out=\"999999\">");
+	playlist.append("<track producer=\"playlist0\"/><track producer=\"playlist1\"/>");
+	playlist.append("</tractor></mlt>");
     }
-    playlist.append("<tractor id=\"tractor0\" title=\"video0\" global_feed=\"1\" in=\"0\" out=\"999999\">");
-    if (rec_video->isChecked()) playlist.append("<track producer=\"playlist0\"/>");
-    if (rec_audio->isChecked()) playlist.append("<track producer=\"playlist1\"/>");
-    playlist.append("</tractor></mlt>");
-
+    else if (rec_audio->isChecked()) {
+	// Audio only recording
+	*isXml = false;
+	playlist =QString("alsa:%1?channels=%2").arg(KdenliveSettings::v4l_alsadevicename()).arg(KdenliveSettings::alsachannels());
+    }
+    else {
+	// Video only recording
+	*isXml = false;
+	playlist =QString("video4linux2:%1?width:%2&amp;height:%3&amp;frame_rate:%4").arg(KdenliveSettings::video4vdevice()).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den);
+	
+    }
+    
     return playlist;
 }
 
@@ -790,7 +872,7 @@ void RecMonitor::slotStartGrab(const QRect &rect) {
         alsaProcess->start("arecord", alsaArgs);
     }
     kDebug() << "Capture: Running ffmpeg " << m_captureArgs.join(" ");
-    captureProcess->start("ffmpeg", m_captureArgs);
+    captureProcess->start(KdenliveSettings::ffmpegpath(), m_captureArgs);
 }*/
 
 void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
@@ -810,19 +892,23 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
             m_fwdAction->setEnabled(false);
             m_recAction->setEnabled(false);
         }
+        else {
+	    m_recAction->setEnabled(true);
+	}
         m_isPlaying = false;
         m_playAction->setIcon(m_playIcon);
         m_recAction->setChecked(false);
         m_stopAction->setEnabled(false);
         device_selector->setEnabled(true);
         if (m_captureProcess && m_captureProcess->exitStatus() == QProcess::CrashExit) {
-            video_frame->setText(i18n("Capture crashed, please check your parameters"));
+	    showWarningMessage(i18n("Capture crashed, please check your parameters"), true);
         } else {
             if (device_selector->currentIndex() != SCREENGRAB) {
                 video_frame->setText(i18n("Not connected"));
             } else {
-                if (m_captureProcess->exitCode() != 0) {
-                    video_frame->setText(i18n("Capture crashed, please check your parameters\nRecordMyDesktop exit code: %1", QString::number(m_captureProcess->exitCode())));
+		int code = m_captureProcess->exitCode();
+                if (code != 0 && code != 255) {
+                    showWarningMessage(i18n("Capture crashed, please check your parameters"), true);
                 } else {
                     video_frame->setPixmap(mergeSideBySide(KIcon("video-display").pixmap(QSize(50, 50)), i18n("Press record button\nto start screen capture\nFiles will be saved in:\n%1", m_capturePath)));
                 }
@@ -834,7 +920,7 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
         // update free space info
         slotUpdateFreeSpace();
     } else {
-        if (device_selector->currentIndex() != SCREENGRAB) m_stopAction->setEnabled(true);
+        if (device_selector->currentIndex()) m_stopAction->setEnabled(true);
         device_selector->setEnabled(false);
     }
 }
@@ -858,7 +944,7 @@ void RecMonitor::manageCapturedFiles()
     QStringList filters;
     QString capturename = KdenliveSettings::dvgrabfilename();
     if (capturename.isEmpty()) capturename = "capture";
-    filters << capturename + "*" + extension;
+    filters << capturename + '*' + extension;
     const QStringList result = dir.entryList(filters, QDir::Files, QDir::Time);
     KUrl::List capturedFiles;
     foreach(const QString & name, result) {
@@ -884,7 +970,7 @@ void RecMonitor::manageCapturedFiles()
     kDebug() << capturedFiles;
 
     if (capturedFiles.count() > 0) {
-        ManageCapturesDialog *d = new ManageCapturesDialog(capturedFiles, this);
+        QPointer<ManageCapturesDialog> d = new ManageCapturesDialog(capturedFiles, this);
         if (d->exec() == QDialog::Accepted) {
             emit addProjectClipList(d->importFiles());
         }
@@ -923,12 +1009,22 @@ void RecMonitor::slotPlay()
     else slotStartPreview(true);*/
 }
 
-void RecMonitor::slotReadDvgrabInfo()
+void RecMonitor::slotReadProcessInfo()
 {
     QString data = m_captureProcess->readAllStandardError().simplified();
-    data = data.section('"', 2, 2).simplified();
-    m_dvinfo.setText(data.left(11));
-    m_dvinfo.updateGeometry();
+    if (device_selector->currentIndex() == SCREENGRAB) {
+	m_error.append(data + "\n");
+    }
+    else if (device_selector->currentIndex() == FIREWIRE) {
+	data = data.section('"', 2, 2).simplified();
+	m_dvinfo.setText(data.left(11));
+	m_dvinfo.updateGeometry();
+    }
+}
+
+void RecMonitor::slotShowLog()
+{
+    KMessageBox::information(this, m_error);
 }
 
 AbstractRender *RecMonitor::abstractRender()
