@@ -83,7 +83,8 @@ AbstractScopeWidget::AbstractScopeWidget(bool trackMouse, QWidget *parent) :
     m_aRealtime->setCheckable(true);
 
     m_menu = new QMenu(this);
-    m_menu->setPalette(m_scopePalette);
+    // Disabled dark palette on menus since it breaks up with some themes: kdenlive issue #2950
+    //m_menu->setPalette(m_scopePalette);
     m_menu->addAction(m_aAutoRefresh);
     m_menu->addAction(m_aRealtime);
 
