@@ -11,12 +11,10 @@ class VideoGLWidget : public QGLWidget
 public:
     VideoGLWidget(QWidget *parent = 0);
     ~VideoGLWidget();
-
+    void activateMonitor();
     QSize minimumSizeHint() const;
     QSize sizeHint() const;
-    void setImageAspectRatio(double ratio) {
-        m_display_ratio = ratio;
-    }
+    void setImageAspectRatio(double ratio);
     void setBackgroundColor(QColor color) {
         m_backgroundColor = color;
     }
